package it.unibo.stradivarius.tricksandthreats;

import androidx.appcompat.app.AppCompatActivity;

import android.Manifest;
import android.app.AlarmManager;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.pm.PackageManager;
import android.net.Uri;
import android.os.BatteryManager;
import android.os.Bundle;
import android.os.SystemClock;
import android.os.Vibrator;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;

public class MainActivity extends AppCompatActivity implements View.OnClickListener {

    private Vibrator vibrator;
    private AlarmManager alarmManager;
    private BatteryManager batteryManager;

    TextView tvBatteryStatus;
    TextView tvBatteryPercentage;

    EditText etAlarm;

    Button btnStartVibrate;
    Button btnStopVibrate;
    Button btnStartVibrationPattern;
    Button btnAlarm;
    Button btnSensors;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        if(checkSelfPermission(Manifest.permission.VIBRATE) != PackageManager.PERMISSION_GRANTED)
            requestPermissions(new String[]{Manifest.permission.VIBRATE}, 0);

        vibrator = (Vibrator)getSystemService(Context.VIBRATOR_SERVICE);
        alarmManager = (AlarmManager)getSystemService(Context.ALARM_SERVICE);
        batteryManager = (BatteryManager) getSystemService(BATTERY_SERVICE);

        tvBatteryPercentage = findViewById(R.id.tvBatteryPercentage);
        tvBatteryStatus = findViewById(R.id.tvBatteryStatus);

        etAlarm = findViewById(R.id.etAlarm);

        btnStartVibrate = findViewById(R.id.btnStartVibrate);
        btnStopVibrate = findViewById(R.id.btnStopVibrate);
        btnStartVibrationPattern = findViewById(R.id.btnStartVibrationPattern);
        btnAlarm = findViewById(R.id.btnAlarm);
        btnSensors = findViewById(R.id.btnSensors);

        btnStartVibrate.setOnClickListener(this);
        btnStopVibrate.setOnClickListener(this);
        btnStartVibrationPattern.setOnClickListener(this);
        btnAlarm.setOnClickListener(this);
        btnSensors.setOnClickListener(this);

        BroadcastReceiver broadcastReceiver = new BroadcastReceiver() {
            @Override
            public void onReceive(Context context, Intent intent) {
                int status = intent.getIntExtra(BatteryManager.EXTRA_STATUS, -1);
                boolean isCharging = status == BatteryManager.BATTERY_STATUS_CHARGING ||
                        status == BatteryManager.BATTERY_STATUS_FULL;

                if (isCharging) {
                    tvBatteryStatus.setText("CHARGING");
                } else {
                    tvBatteryStatus.setText("DISCHARGING");
                }
                tvBatteryPercentage.setText(String.valueOf(intent.getIntExtra(BatteryManager.EXTRA_LEVEL, -1) * 100 /
                        (float)intent.getIntExtra(BatteryManager.EXTRA_SCALE, -1)));
                //tvBatteryPercentage.setText(String.valueOf(batteryManager.getIntProperty(BatteryManager.BATTERY_PROPERTY_CAPACITY)));
            }
        };
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction("android.intent.action.BATTERY_CHANGED");
        this.registerReceiver(broadcastReceiver, intentFilter);
    }

    public void startVibrate(){
        vibrator.vibrate(5000);
    }

    public void stopVibrate(){
        vibrator.cancel();
    }

    public void startVibratePattern(){
        long[] pattern = new long[]{500,500,1000,500,2000, 500, 3000, 500, 4000, 500, 5000, 500};
        vibrator.vibrate(pattern, -1);
    }

    @Override
    public void onClick(View v) {
        if (v == btnStartVibrate) {
            startVibrate();
        } else if (v == btnStopVibrate) {
            stopVibrate();
        } else if (v == btnStartVibrationPattern) {
            startVibratePattern();
        } else if (v == btnAlarm) {
            PendingIntent pendingIntent;
            Intent intent = new Intent(Intent.ACTION_VIEW);
            intent.setData(Uri.parse("http://www.unibo.it"));
            pendingIntent = PendingIntent.getActivity(this, 0, intent,0);
            alarmManager.set(AlarmManager.ELAPSED_REALTIME, SystemClock.elapsedRealtime() + Integer.valueOf(etAlarm.getText().toString()) * 1000, pendingIntent);
        } else if (v == btnSensors) {
            Intent i = new Intent(this, SensorsActivity.class);
            startActivity(i);
        }
    }
}
